@@ -8,7 +8,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: bspclean.c,v 1.11 2004/04/08 05:29:32 ralf Exp $
+ *  $Id$
  */
 
 #include <rtems.h>
@@ -16,10 +16,10 @@
 #include <rtems/clockdrv.h>
 #include <rtems/zilog/z8036.h>
 
-void bsp_return_to_monitor_trap()
-{
-  extern void start( void  );
+extern void start( void  );
 
+void bsp_return_to_monitor_trap(void)
+{
   register volatile void *start_addr;
 
   m68k_set_vbr( 0 );                /* restore 135Bug vectors */
