@@ -1,15 +1,14 @@
-/*  vmeintr.c
- *
+/*
  *  VMEbus support routines for the Generation I board.
  *
- *  COPYRIGHT (c) 1989-1997.
+ *  COPYRIGHT (c) 1989-2008.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may in
  *  the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id:
+ *  $Id$
  */
 
 #include <rtems.h>
@@ -26,18 +25,12 @@ void VME_interrupt_Disable (
   VME_interrupt_Mask                mask                        /* IN  */
 )
 {
-  volatile uint8_t          *VME_interrupt_enable;
-  uint8_t          value;
+  volatile uint8_t  *VME_interrupt_enable;
+  uint8_t           value;
 
-#if 0
-  VME_interrupt_enable = ACC_VIE;
-#else
   VME_interrupt_enable = 0;
-#endif
   value = *VME_interrupt_enable;
-
   value &= ~mask;  /* turn off interrupts for all levels in mask */
-
   *VME_interrupt_enable = value;
 }
 
@@ -54,14 +47,8 @@ void VME_interrupt_Enable (
   volatile uint8_t          *VME_interrupt_enable;
   uint8_t          value;
 
-#if 0
-  VME_interrupt_enable = ACC_VIE;
-#else
   VME_interrupt_enable = 0;
-#endif
   value = *VME_interrupt_enable;
-
   value |= mask;  /* turn on interrupts for all levels in mask */
-
   *VME_interrupt_enable = value;
 }
