@@ -3,13 +3,13 @@
  * Support for gnat/rtems interrupts and exception handling.
  * Jiri Gaisler, ESA/ESTEC, 17-02-1999.
  *
- *  $Id: gnatsupp.c,v 1.5 2000/12/06 15:44:07 joel Exp $
+ *  $Id$
  */
 
 void __gnat_install_handler_common( int, int );
 
 void
-__gnat_install_handler ()
+__gnat_install_handler (void)
 {
   __gnat_install_handler_common (0x1d, 0x15);
 }
