@@ -6,7 +6,7 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: cal_por.c,v 1.1 2007/04/17 20:32:12 joel Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -22,11 +22,11 @@
  */
 
 ER cal_por(
-  VP    msg,
-  INT  *p_rmsgsz,
-  ID    porid,
-  UINT  calptn,
-  INT   cmsgsz
+  VP    msg __attribute__((unused)),
+  INT  *p_rmsgsz __attribute__((unused)),
+  ID    porid __attribute__((unused)),
+  UINT  calptn __attribute__((unused)),
+  INT   cmsgsz __attribute__((unused))
 )
 {
   return E_OK;
