@@ -1,9 +1,13 @@
 /*
  * RTEMS multi-tasking support
  *
- * $Id: rtems_rpc.c,v 1.4 2004/03/05 17:58:51 joel Exp $
+ * $Id$
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <rpc/rpc.h>
 #include <rtems.h>
 #include <stdlib.h>
@@ -13,6 +17,23 @@
  */
 static struct _rtems_rpc_task_variables rpc_default = {
 	-1,		/* svc_maxfd */
+	{{0}},		/* svc_svc_fdset */
+	NULL,		/* svc_xports */
+	0,		/* svc_xportssize */
+	0,		/* svc__svc_fdsetsize */		
+	0,		/* svc__svc_fdset */
+	NULL,		/* svc_svc_head */
+	0,		/* clnt_perror_buf */
+	0,		/* clnt_raw_private */
+	0,		/* call_rpc_private */
+	0,		/* svc_raw_private */
+
+	0,		/* svc_simple_proglst */
+	0,		/* svc_simple_pl */
+	0,		/* svc_simple_transp */
+
+	0,		/* rpcdname_default_domain */
+	0		/* svc_auths_Auths */
 };
 
 /*
@@ -20,6 +41,23 @@ static struct _rtems_rpc_task_variables rpc_default = {
  */
 static const struct _rtems_rpc_task_variables rpc_init = {
 	-1,		/* svc_maxfd */
+	{{0}},		/* svc_svc_fdset */
+	NULL,		/* svc_xports */
+	0,		/* svc_xportssize */
+	0,		/* svc__svc_fdsetsize */		
+	0,		/* svc__svc_fdset */
+	NULL,		/* svc_svc_head */
+	0,		/* clnt_perror_buf */
+	0,		/* clnt_raw_private */
+	0,		/* call_rpc_private */
+	0,		/* svc_raw_private */
+
+	0,		/* svc_simple_proglst */
+	0,		/* svc_simple_pl */
+	0,		/* svc_simple_transp */
+
+	0,		/* rpcdname_default_domain */
+	0		/* svc_auths_Auths */
 };
 
 /*
