@@ -3,10 +3,15 @@
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: cpu.c,v 1.1 2005/02/12 06:19:20 ralf Exp $
+ *  $Id$
  */
 
 /*
  * For now, this file is just a stub to work around
  * structural deficiencies of the powerpc port.
  */
+
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
